#ifndef __PLUGIN__
#define __PLUGIN__

#ifdef __cplusplus
extern "C" {
#endif

#include <X11/Xlib.h>
#include "font.h"
#include "options.h"
#include "pixmap.h"

#define INIT_SYM "Init"

typedef struct _tagPANELINFO
{
  Window wnd;
  const char *name;
} PANELINFO,*LPPANELINFO;

struct _tagMODULE;

typedef void (*MODULE_EVENTHANDLER)(struct _tagMODULE *,XEvent *pEvent);
typedef void (*MODULE_DESTROY)(struct _tagMODULE *);
typedef void (*MODULE_TIMEOUT)(struct _tagMODULE *);
typedef const char *(*MODULE_GETTOOLTIP)(struct _tagMODULE *);

typedef struct _tagMODULE
{
  MODULE_EVENTHANDLER EventHandler;
  MODULE_DESTROY      Destroy;
  MODULE_TIMEOUT      Timeout;
  MODULE_GETTOOLTIP   GetTooltip;
  int numPanels;
  PANELINFO panels[1];
} MODULE,*LPMODULE;

typedef struct _tagPIXMAPFUNCS
{
  int (*LoadPixmap)(char **pData,LPPIXMAP pMap);
  int (*LoadPixmapFromFile)(const char *pFile,LPPIXMAP pMap);
  void (*FreePixmap)(LPPIXMAP pMap);
  void (*UpdatePixmapAttributes)(LPPIXMAP pMap);
  void (*RenderPixmap)(Display *pDisp,Drawable draw,GC gc,int x,int y,LPPIXMAP pMap);
  int (*ScalePixmap)(Display *display, Window window,LPPIXMAP src,LPPIXMAP dest);
} PIXMAPFUNCS,*LPPIXMAPFUNCS;

typedef struct _tagLIBRARYINIT
{
  /* in */
  Display *pDisplay;
  int screen;
  Window root;
  Window panelWindow;
  unsigned long backgroundPixel;
  unsigned int height;
  unsigned int baseInputMask;
  LPFONT pFont;
  LPCONFIGITEM pOptions;
  PIXMAPFUNCS pixmapFuncs;
  /* out */
  LPMODULE pModule;
} LIBRARYINIT,*LPLIBRARYINIT;

/* Plugins must implement this function and set the out parameter *pModule
   in the LPLIBRARYINIT structure.  Return non-zero on success, 0 on failure.
*/
typedef int (*LIBINIT)(LPLIBRARYINIT pInit);

#ifdef __cplusplus
}
#endif
#endif

